@@ -21,7 +21,7 @@ func newApp() *cobra.Command {
 		Version: strings.TrimPrefix(version.Version, "v"),
 	}
 	rootCmd.PersistentFlags().Bool("debug", false, "debug mode")
-	rootCmd.PersistentPreRunE = func(cmd *cobra.Command, args []string) error {
+	rootCmd.PersistentPreRunE = func(cmd *cobra.Command, _ []string) error {
 		debug, _ := cmd.Flags().GetBool("debug")
 		if debug {
 			logrus.SetLevel(logrus.DebugLevel)
