@@ -8,6 +8,7 @@ import (
 	"runtime"
 	"strings"
 
+	"github.com/lima-vm/lima/pkg/fsutil"
 	"github.com/lima-vm/lima/pkg/osutil"
 	"github.com/lima-vm/lima/pkg/store/dirnames"
 	"github.com/lima-vm/lima/pkg/version"
@@ -62,7 +63,7 @@ func newApp() *cobra.Command {
 	rootCmd.PersistentFlags().Bool("debug", false, "debug mode")
 	// TODO: "survey" does not support using cygwin terminal on windows yet
 	rootCmd.PersistentFlags().Bool("tty", isatty.IsTerminal(os.Stdout.Fd()), "Enable TUI interactions such as opening an editor. Defaults to true when stdout is a terminal. Set to false for automation.")
-	rootCmd.PersistentPreRunE = func(cmd *cobra.Command, args []string) error {
+	rootCmd.PersistentPreRunE = func(cmd *cobra.Command, _ []string) error {
 		l, _ := cmd.Flags().GetString("log-level")
 		if l != "" {
 			lvl, err := logrus.ParseLevel(l)
@@ -88,13 +89,27 @@ func newApp() *cobra.Command {
 			logrus.StandardLogger().SetFormatter(formatter)
 		}
 		if os.Geteuid() == 0 && cmd.Name() != "generate-doc" {
-			return errors.New("must not run as the root")
+			return errors.New("must not run as the root user")
 		}
 		// Make sure either $HOME or $LIMA_HOME is defined, so we don't need
 		// to check for errors later
-		if _, err := dirnames.LimaDir(); err != nil {
+		dir, err := dirnames.LimaDir()
+		if err != nil {
 			return err
 		}
+		// Make sure that directory is on a local filesystem, not on NFS
+		// if the directory does not yet exist, check the home directory
+		_, err = os.Stat(dir)
+		if errors.Is(err, os.ErrNotExist) {
+			dir = filepath.Dir(dir)
+		}
+		nfs, err := fsutil.IsNFS(dir)
+		if err != nil {
+			return err
+		}
+		if nfs {
+			return errors.New("must not run on NFS dir")
+		}
 		return nil
 	}
 	rootCmd.AddGroup(&cobra.Group{ID: "basic", Title: "Basic Commands:"})
@@ -141,12 +156,12 @@ func handleExitCoder(err error) {
 	}
 
 	if exitErr, ok := err.(ExitCoder); ok {
-		os.Exit(exitErr.ExitCode())
+		os.Exit(exitErr.ExitCode()) //nolint:revive // it's intentional to call os.Exit in this function
 		return
 	}
 }
 
-// WrapArgsError annotates cobra args error with some context, so the error message is more user-friendly
+// WrapArgsError annotates cobra args error with some context, so the error message is more user-friendly.
 func WrapArgsError(argFn cobra.PositionalArgs) cobra.PositionalArgs {
 	return func(cmd *cobra.Command, args []string) error {
 		err := argFn(cmd, args)
