@@ -5,6 +5,7 @@ import (
 	"github.com/lima-vm/lima/pkg/limayaml"
 	"github.com/lima-vm/lima/pkg/qemu"
 	"github.com/lima-vm/lima/pkg/vz"
+	"github.com/lima-vm/lima/pkg/wsl2"
 )
 
 func CreateTargetDriverInstance(base *driver.BaseDriver) driver.Driver {
@@ -12,5 +13,8 @@ func CreateTargetDriverInstance(base *driver.BaseDriver) driver.Driver {
 	if *limaDriver == limayaml.VZ {
 		return vz.New(base)
 	}
+	if *limaDriver == limayaml.WSL2 {
+		return wsl2.New(base)
+	}
 	return qemu.New(base)
 }
