@@ -7,6 +7,7 @@ import (
 	"os"
 	"path"
 	"path/filepath"
+	"regexp"
 	"runtime"
 	"strings"
 
@@ -40,7 +41,7 @@ func validateFileObject(f File, fieldName string) error {
 	return nil
 }
 
-func Validate(y LimaYAML, warn bool) error {
+func Validate(y *LimaYAML, warn bool) error {
 	switch *y.OS {
 	case LINUX:
 	default:
@@ -183,9 +184,10 @@ func Validate(y LimaYAML, warn bool) error {
 					i, ProvisionModeDependency)
 			}
 		case ProvisionModeDependency:
+		case ProvisionModeAnsible:
 		default:
-			return fmt.Errorf("field `provision[%d].mode` must one of %q, %q, %q, or %q",
-				i, ProvisionModeSystem, ProvisionModeUser, ProvisionModeBoot, ProvisionModeDependency)
+			return fmt.Errorf("field `provision[%d].mode` must one of %q, %q, %q, %q, or %q",
+				i, ProvisionModeSystem, ProvisionModeUser, ProvisionModeBoot, ProvisionModeDependency, ProvisionModeAnsible)
 		}
 		if strings.Contains(p.Script, "LIMA_CIDATA") {
 			logrus.Warn("provisioning scripts should not reference the LIMA_CIDATA variables")
@@ -251,7 +253,7 @@ func Validate(y LimaYAML, warn bool) error {
 		}
 		if rule.GuestSocket != "" {
 			if !path.IsAbs(rule.GuestSocket) {
-				return fmt.Errorf("field `%s.guestSocket` must be an absolute path", field)
+				return fmt.Errorf("field `%s.guestSocket` must be an absolute path, but is %q", field, rule.GuestSocket)
 			}
 			if rule.HostSocket == "" && rule.HostPortRange[1]-rule.HostPortRange[0] > 0 {
 				return fmt.Errorf("field `%s.guestSocket` can only be mapped to a single port or socket. not a range", field)
@@ -286,7 +288,7 @@ func Validate(y LimaYAML, warn bool) error {
 		field := fmt.Sprintf("CopyToHost[%d]", i)
 		if rule.GuestFile != "" {
 			if !path.IsAbs(rule.GuestFile) {
-				return fmt.Errorf("field `%s.guest` must be an absolute path", field)
+				return fmt.Errorf("field `%s.guest` must be an absolute path, but is %q", field, rule.GuestFile)
 			}
 		}
 		if rule.HostFile != "" {
@@ -309,11 +311,12 @@ func Validate(y LimaYAML, warn bool) error {
 	return nil
 }
 
-func validateNetwork(y LimaYAML) error {
+func validateNetwork(y *LimaYAML) error {
 	interfaceName := make(map[string]int)
 	for i, nw := range y.Networks {
 		field := fmt.Sprintf("networks[%d]", i)
-		if nw.Lima != "" {
+		switch {
+		case nw.Lima != "":
 			config, err := networks.Config()
 			if err != nil {
 				return err
@@ -334,7 +337,7 @@ func validateNetwork(y LimaYAML) error {
 			if nw.VZNAT != nil && *nw.VZNAT {
 				return fmt.Errorf("field `%s.lima` and field `%s.vzNAT` are mutually exclusive", field, field)
 			}
-		} else if nw.Socket != "" {
+		case nw.Socket != "":
 			if nw.VZNAT != nil && *nw.VZNAT {
 				return fmt.Errorf("field `%s.socket` and field `%s.vzNAT` are mutually exclusive", field, field)
 			}
@@ -343,7 +346,7 @@ func validateNetwork(y LimaYAML) error {
 			} else if err == nil && fi.Mode()&os.ModeSocket == 0 {
 				return fmt.Errorf("field `%s.socket` %q points to a non-socket file", field, nw.Socket)
 			}
-		} else if nw.VZNAT != nil && *nw.VZNAT {
+		case nw.VZNAT != nil && *nw.VZNAT:
 			if y.VMType == nil || *y.VMType != VZ {
 				return fmt.Errorf("field `%s.vzNAT` requires `vmType` to be %q", field, VZ)
 			}
@@ -353,7 +356,7 @@ func validateNetwork(y LimaYAML) error {
 			if nw.Socket != "" {
 				return fmt.Errorf("field `%s.vzNAT` and field `%s.socket` are mutually exclusive", field, field)
 			}
-		} else {
+		default:
 			return fmt.Errorf("field `%s.lima` or  field `%s.socket must be set", field, field)
 		}
 		if nw.MACAddress != "" {
@@ -383,6 +386,46 @@ func validateNetwork(y LimaYAML) error {
 	return nil
 }
 
+// ValidateParamIsUsed checks if the keys in the `param` field are used in any script, probe, copyToHost, or portForward.
+// It should be called before the `y` parameter is passed to FillDefault() that execute template.
+func ValidateParamIsUsed(y *LimaYAML) error {
+	for key := range y.Param {
+		re, err := regexp.Compile(`{{[^}]*\.Param\.` + key + `[^}]*}}`)
+		if err != nil {
+			return fmt.Errorf("field to compile regexp for key %q: %w", key, err)
+		}
+		keyIsUsed := false
+		for _, p := range y.Provision {
+			if re.MatchString(p.Script) {
+				keyIsUsed = true
+				break
+			}
+		}
+		for _, p := range y.Probes {
+			if re.MatchString(p.Script) {
+				keyIsUsed = true
+				break
+			}
+		}
+		for _, p := range y.CopyToHost {
+			if re.MatchString(p.GuestFile) || re.MatchString(p.HostFile) {
+				keyIsUsed = true
+				break
+			}
+		}
+		for _, p := range y.PortForwards {
+			if re.MatchString(p.GuestSocket) || re.MatchString(p.HostSocket) {
+				keyIsUsed = true
+				break
+			}
+		}
+		if !keyIsUsed {
+			return fmt.Errorf("field `param` key %q is not used in any provision, probe, copyToHost, or portForward", key)
+		}
+	}
+	return nil
+}
+
 func validatePort(field string, port int) error {
 	switch {
 	case port < 0:
@@ -397,7 +440,7 @@ func validatePort(field string, port int) error {
 	return nil
 }
 
-func warnExperimental(y LimaYAML) {
+func warnExperimental(y *LimaYAML) {
 	if *y.MountType == NINEP {
 		logrus.Warn("`mountType: 9p` is experimental")
 	}
