@@ -8,10 +8,10 @@ import (
 // UnixPathMax is the value of UNIX_PATH_MAX.
 const UnixPathMax = 108
 
-// Stat is a selection of syscall.Stat_t
+// Stat is a selection of syscall.Stat_t.
 type Stat struct {
-	Uid uint32 //nolint:revive
-	Gid uint32 //nolint:revive
+	Uid uint32
+	Gid uint32
 }
 
 func SysStat(fi fs.FileInfo) (Stat, bool) {
