@@ -43,12 +43,12 @@ type Config struct {
 	SSHLocalPort int
 }
 
-// MinimumQemuVersion is the minimum supported QEMU version
+// MinimumQemuVersion is the minimum supported QEMU version.
 const (
 	MinimumQemuVersion = "4.0.0"
 )
 
-// EnsureDisk also ensures the kernel and the initrd
+// EnsureDisk also ensures the kernel and the initrd.
 func EnsureDisk(ctx context.Context, cfg Config) error {
 	diffDisk := filepath.Join(cfg.InstanceDir, filenames.DiffDisk)
 	if _, err := os.Stat(diffDisk); err == nil || !errors.Is(err, os.ErrNotExist) {
@@ -227,7 +227,7 @@ func Load(cfg Config, run bool, tag string) error {
 	return err
 }
 
-// List returns a space-separated list of all snapshots, with header and newlines
+// List returns a space-separated list of all snapshots, with header and newlines.
 func List(cfg Config, run bool) (string, error) {
 	if run {
 		out, err := sendHmpCommand(cfg, "info", "snapshots")
@@ -455,7 +455,7 @@ func adjustMemBytesDarwinARM64HVF(memBytes int64, accel string, features *featur
 	return memBytes
 }
 
-// qemuMachine returns string to use for -machine
+// qemuMachine returns string to use for -machine.
 func qemuMachine(arch limayaml.Arch) string {
 	if arch == limayaml.X8664 {
 		return "q35"
@@ -463,6 +463,19 @@ func qemuMachine(arch limayaml.Arch) string {
 	return "virt"
 }
 
+// audioDevice returns the default audio device.
+func audioDevice() string {
+	switch runtime.GOOS {
+	case "darwin":
+		return "coreaudio"
+	case "linux":
+		return "pa" // pulseaudio
+	case "windows":
+		return "dsound"
+	}
+	return "oss"
+}
+
 func Cmdline(ctx context.Context, cfg Config) (exe string, args []string, err error) {
 	y := cfg.LimaYAML
 	exe, args, err = Exe(*y.Arch)
@@ -762,6 +775,9 @@ func Cmdline(ctx context.Context, cfg Config) (exe string, args []string, err er
 		id := "default"
 		// audio device
 		audiodev := *y.Audio.Device
+		if audiodev == "default" {
+			audiodev = audioDevice()
+		}
 		audiodev += fmt.Sprintf(",id=%s", id)
 		args = append(args, "-audiodev", audiodev)
 		// audio controller
@@ -982,7 +998,7 @@ func FindVirtiofsd(qemuExe string) (string, error) {
 		}
 	}
 
-	return "", errors.New("Failed to locate virtiofsd")
+	return "", errors.New("failed to locate virtiofsd")
 }
 
 func VirtiofsdCmdline(cfg Config, mountIndex int) ([]string, error) {
@@ -1004,7 +1020,7 @@ func VirtiofsdCmdline(cfg Config, mountIndex int) ([]string, error) {
 	}, nil
 }
 
-// qemuArch returns the arch string used by qemu
+// qemuArch returns the arch string used by qemu.
 func qemuArch(arch limayaml.Arch) string {
 	if arch == limayaml.ARMV7L {
 		return "arm"
@@ -1100,17 +1116,21 @@ func getFirmware(qemuExe string, arch limayaml.Arch) (string, error) {
 		// Debian package "ovmf"
 		candidates = append(candidates, "/usr/share/OVMF/OVMF_CODE.fd")
 		candidates = append(candidates, "/usr/share/OVMF/OVMF_CODE_4M.fd")
+		// Fedora package "edk2-ovmf"
+		candidates = append(candidates, "/usr/share/edk2/ovmf/OVMF_CODE.fd")
 		// openSUSE package "qemu-ovmf-x86_64"
 		candidates = append(candidates, "/usr/share/qemu/ovmf-x86_64-code.bin")
 		// Archlinux package "edk2-ovmf"
 		candidates = append(candidates, "/usr/share/edk2-ovmf/x64/OVMF_CODE.fd")
 	case limayaml.AARCH64:
 		// Debian package "qemu-efi-aarch64"
+		// Fedora package "edk2-aarch64"
 		candidates = append(candidates, "/usr/share/AAVMF/AAVMF_CODE.fd")
 		// Debian package "qemu-efi-aarch64" (unpadded, backwards compatibility)
 		candidates = append(candidates, "/usr/share/qemu-efi-aarch64/QEMU_EFI.fd")
 	case limayaml.ARMV7L:
 		// Debian package "qemu-efi-arm"
+		// Fedora package "edk2-arm"
 		candidates = append(candidates, "/usr/share/AAVMF/AAVMF32_CODE.fd")
 	}
 
